==> downloads_LightNEasy_2_2_1_flat.zip: languages/lang_en_US.php <==
<?php
/*---------------------------------------------------+
| LightNEasy Content Management System
| Language module lang_en_US.php
| version 2.2
+----------------------------------------------------+
| Copyright 2007 - 2008 Fernando Baptista
| http://lightneasy.org
+----------------------------------------------------+
| Released under the terms & conditions of v2 of the
| GNU General Public License. For details refer to
| the included gpl.txt file or visit http://gnu.org
+----------------------------------------------------*/

$langmessage[0]  = "Error - Could not open database";
$langmessage[1]  = "Error - Could not read the settings";
$langmessage[2]  = "Error - Could not read the download categories";
$langmessage[3]  = "Error - Could not read the downloads";
$langmessage[4]  = "Error - Could not read the link categories";
$langmessage[5]  = "Could not read the links";
$langmessage[6]  = "Password";
$langmessage[7]  = "Admin name";
$langmessage[8]  = "Admin email";
$langmessage[9]  = "Website email";
$langmessage[10] = "Path to your website";
$langmessage[11] = "Template";
$langmessage[12] = "Title";
$langmessage[13] = "Subtitle";
$langmessage[14] = "Keywords";
$langmessage[15] = "Description";
$langmessage[16] = "Author";
$langmessage[17] = "Footer";
$langmessage[18] = "Use Gzip compressor";
$langmessage[19] = "Start File";
$langmessage[20] = "Lightneasy language";
$langmessage[21] = "TinyMCE language";
$langmessage[22] = "Could not save the settings";
$langmessage[25] = "Save Setup";
$langmessage[26] = "Message sent";
$langmessage[27] = "Message from ";
$langmessage[28] = "error sending mail";
$langmessage[29] = "Message empty";
$langmessage[30] = "Your name";
$langmessage[31] = "Your e-mail";
$langmessage[32] = "Your message";
$langmessage[33] = "Send message";
$langmessage[34] = "LightNEasy Administration";
$langmessage[35] = "New Page";
$langmessage[36] = "Extra";
$langmessage[37] = "News";
$langmessage[38] = "Images";
$langmessage[39] = "Downloads";
$langmessage[40] = "Links";
$langmessage[41] = "Menu";
$langmessage[42] = "Generate";
$langmessage[43] = "Database";
$langmessage[44] = "Setup";
$langmessage[45] = "Query Database";
$langmessage[46] = "Query submited";
$langmessage[47] = "Query";
$langmessage[48] = "Downloads";
$langmessage[49] = "Download Categories";
$langmessage[50] = "Name";
$langmessage[51] = "Filename";
$langmessage[52] = "Category";
$langmessage[53] = "Add Category";
$langmessage[54] = "Edit Category";
$langmessage[55] = "Add Download";
$langmessage[56] = "Edit Download";
$langmessage[57] = "Upload Images and Files";
$langmessage[58] = "Upload image";
$langmessage[59] = "Select image to upload";
$langmessage[60] = "Image name or";
$langmessage[61] = "Upload to Gallery";
$langmessage[62] = "Create Gallery";
$langmessage[63] = "Could not create galery folder";
$langmessage[64] = "Gallery created";
$langmessage[65] = "Gallery already exists";
$langmessage[66] = "Link Categories";
$langmessage[67] = "Description";
$langmessage[68] = "Link Name";
$langmessage[69] = "Link";
$langmessage[70] = "Edit Link";
$langmessage[71] = "Add Link";
$langmessage[72] = "News Administration";
$langmessage[73] = "E-mail";
$langmessage[74] = "Add News";
$langmessage[75] = "News added successfully.";
$langmessage[76] = "Unknown error while saving news.";
$langmessage[77] = "Edit News";
$langmessage[78] = "News Categories";
$langmessage[79] = "Cat. id";
$langmessage[80] = "All news";
$langmessage[81] = "viewed";
$langmessage[82] = "New Page";
$langmessage[83] = "Menu Level";
$langmessage[84] = "File name";
$langmessage[85] = "Menu Label";
$langmessage[86] = "Create Page";
$langmessage[87] = "Page Created";
$langmessage[88] = "Site Map";
$langmessage[89] = "Edit Extra Content";
$langmessage[90] = "LightNEasy 1.2 Login Form";
$langmessage[91] = "Edit Menu";
$langmessage[92] = "Edit Menu Entry";
$langmessage[93] = "Delete Menu Entry";
$langmessage[94] = "Select";
$langmessage[95] = "Login Successfull";
$langmessage[96] = "Login incorrect!";
$langmessage[97] = "Incomplete Input";
$langmessage[98] = "Hijacking attempt, dying....";
$langmessage[99] = "Code";
$langmessage[100]= "No downloads present";
$langmessage[101]= "Field(s) empty";
$langmessage[102]= "Page saved";
$langmessage[103]= "Extra content saved";
$langmessage[104]= "Page deleted";
$langmessage[105]= "couldn't save download category";
$langmessage[106]= "couldn't save links category";
$langmessage[107]= "couldn't save news category";
$langmessage[108]= "File type not allowed";
$langmessage[109]= "File not found";
$langmessage[110]= "Could not create page ";
$langmessage[111]= "Home";
$langmessage[112]= "Posted at";
$langmessage[113]= "Previous Posts";
$langmessage[114]= "Date";
$langmessage[115]= "Seen";
$langmessage[116]= "No page found!";
$langmessage[117]= "Gallery name";
$langmessage[118]= "This IP address is blocked.";
$langmessage[119]= "Could not save the download";
$langmessage[120]= "Login";
$langmessage[121]= "Logout";
$langmessage[122]= "Upload file";
$langmessage[123]= "There was an error uploading the file, please try again!";
$langmessage[124]= "The file ";
$langmessage[125]= " has been uploaded";
$langmessage[126]= "News category deleted";
$langmessage[127]= "News category already deleted or non-existant";
$langmessage[128]= "News deleted";
$langmessage[129]= "News already deleted or non-existant";
$langmessage[130]= "LightNEasy Setup";
$langmessage[131]= "Are you sure you want to delete the page ";
$langmessage[132]= "Could not save the link";
$langmessage[133]= "Save Menu";
$langmessage[134]= "Menu saved";
$langmessage[135]= "Could not open page ";
$langmessage[136]= "Delete Page";
$langmessage[137]= "Send comment";
$langmessage[138]= "Your comment";
$langmessage[139]= "Wrong code!";
$langmessage[140]= "Insert after";
$langmessage[141]= "Comment added";
$langmessage[142]= "Unknown error while saving comment";
$langmessage[143]= "Comments";
$langmessage[144]= "Poster";
$langmessage[145]= "Time offset from server";
$langmessage[146]= "Restricted page";
$langmessage[147]= "You need to enter the password to access this page";
$langmessage[148]= "Delete";
$langmessage[149]= "Image Deleted";
$langmessage[150]= "Setup Saved";
$langmessage[151]= "Date/time format";
$langmessage[152]= "Edit page";
$langmessage[153]= "Abandon changes";
?>

==> downloads_LightNEasy_2_2_2_flat.zip: languages/lang_en_US.php <==
<?php
/*---------------------------------------------------+
| LightNEasy Content Management System
| Language module lang_en_US.php
| version 3
+----------------------------------------------------+
| Copyright 2007 - 2009 Fernando Baptista
| http://www.lightneasy.org
+----------------------------------------------------+
| Released under the terms & conditions of v2 of the
| GNU General Public License. For details refer to
| the included gpl.txt file or visit http://gnu.org
+----------------------------------------------------*/
$langmessage[0]  = "Error - Could not open database";
$langmessage[1]  = "Error - Could not read the settings";
$langmessage[2]  = "Error - Could not read the download categories";
$langmessage[3]  = "Error - Could not read the downloads";
$langmessage[4]  = "Error - Could not read the link categories";
$langmessage[5]  = "Could not read the links";
$langmessage[6]  = "Password";
$langmessage[7]  = "Admin name";
$langmessage[8]  = "Admin email";
$langmessage[9]  = "Website email";
$langmessage[10] = "Path to your website";
$langmessage[11] = "Template";
$langmessage[12] = "Title";
$langmessage[13] = "Subtitle";
$langmessage[14] = "Keywords";
$langmessage[15] = "Description";
$langmessage[16] = "Author";
$langmessage[17] = "Footer";
$langmessage[18] = "Use Gzip compressor";
$langmessage[19] = "Start File";
$langmessage[20] = "Lightneasy language";
$langmessage[21] = "Editor language";
$langmessage[22] = "Could not save the settings";
$langmessage[25] = "Save Setup";
$langmessage[26] = "Message sent";
$langmessage[27] = "Message from ";
$langmessage[28] = "error sending mail";
$langmessage[29] = "Message empty";
$langmessage[30] = "Your&nbsp;name";
$langmessage[31] = "Your&nbsp;e-mail";
$langmessage[32] = "Your&nbsp;message";
$langmessage[33] = "Send message";
$langmessage[34] = "LightNEasy Administration";
$langmessage[35] = "New Page";
$langmessage[36] = "Extra";
$langmessage[37] = "News";
$langmessage[38] = "Images";
$langmessage[39] = "Downloads";
$langmessage[40] = "Links";
$langmessage[41] = "Menu";
$langmessage[42] = "Generate";
$langmessage[43] = "Database";
$langmessage[44] = "Setup";
$langmessage[45] = "Query Database";
$langmessage[46] = "Query submited";
$langmessage[47] = "Query";
$langmessage[48] = "Downloads";
$langmessage[49] = "Download Categories";
$langmessage[50] = "Name";
$langmessage[51] = "Filename";
$langmessage[52] = "Category";
$langmessage[53] = "Add Category";
$langmessage[54] = "Edit Category";
$langmessage[55] = "Add Download";
$langmessage[56] = "Edit Download";
$langmessage[57] = "Upload Images and Files";
$langmessage[58] = "Upload image";
$langmessage[59] = "Select image to upload";
$langmessage[60] = "Image name or";
$langmessage[61] = "Upload to Gallery";
$langmessage[62] = "Create Gallery";
$langmessage[63] = "Could not create galery folder";
$langmessage[64] = "Gallery created";
$langmessage[65] = "Gallery already exists";
$langmessage[66] = "Link Categories";
$langmessage[67] = "Description";
$langmessage[68] = "Link Name";
$langmessage[69] = "Link";
$langmessage[70] = "Edit Link";
$langmessage[71] = "Add Link";
$langmessage[72] = "News Administration";
$langmessage[73] = "E-mail";
$langmessage[74] = "Add News";
$langmessage[75] = "News added successfully.";
$langmessage[76] = "Unknown error while saving news.";
$langmessage[77] = "Edit News";
$langmessage[78] = "News Categories";
$langmessage[79] = "Cat. id";
$langmessage[80] = "All news";
$langmessage[81] = "viewed";
$langmessage[82] = "Save changes";
$langmessage[83] = "Menu Level";
$langmessage[84] = "File name";
$langmessage[85] = "Menu Label";
$langmessage[86] = "Create Page";
$langmessage[87] = "Page Created";
$langmessage[88] = "Site Map";
$langmessage[89] = "Edit Extra Content";
$langmessage[90] = "LightNEasy 1.2 Login Form";
$langmessage[91] = "Edit Menu";
$langmessage[92] = "Edit Menu Entry";
$langmessage[93] = "Delete Menu Entry";
$langmessage[94] = "Select";
$langmessage[95] = "Login Successfull";
$langmessage[96] = "Login incorrect!";
$langmessage[97] = "Incomplete Input";
$langmessage[98] = "Hijacking attempt, dying....";
$langmessage[99] = "Code";
$langmessage[100]= "No downloads present";
$langmessage[101]= "Field(s) empty";
$langmessage[102]= "Page saved";
$langmessage[103]= "Extra content saved";
$langmessage[104]= "Page deleted";
$langmessage[105]= "couldn't save download category";
$langmessage[106]= "couldn't save links category";
$langmessage[107]= "couldn't save news category";
$langmessage[108]= "File type not allowed";
$langmessage[109]= "File not found";
$langmessage[110]= "Could not create page ";
$langmessage[111]= "Home";
$langmessage[112]= "Posted at";
$langmessage[113]= "Previous Posts";
$langmessage[114]= "Date";
$langmessage[115]= "Seen";
$langmessage[116]= "No page found!";
$langmessage[117]= "Gallery name";
$langmessage[118]= "This IP address is blocked.";
$langmessage[119]= "Could not save the download";
$langmessage[120]= "Login";
$langmessage[121]= "Logout";
$langmessage[122]= "Upload file";
$langmessage[123]= "There was an error uploading the file, please try again!";
$langmessage[124]= "The file ";
$langmessage[125]= " has been uploaded";
$langmessage[126]= "News category deleted";
$langmessage[127]= "News category already deleted or non-existant";
$langmessage[128]= "News deleted";
$langmessage[129]= "News already deleted or non-existant";
$langmessage[130]= "LightNEasy Setup";
$langmessage[131]= "Are you sure you want to delete the page ";
$langmessage[132]= "Could not save the link";
$langmessage[133]= "Save Menu";
$langmessage[134]= "Menu saved";
$langmessage[135]= "Could not open page ";
$langmessage[136]= "Delete Page";
$langmessage[137]= "Send comment";
$langmessage[138]= "Your&nbsp;comment";
$langmessage[139]= "Wrong code!";
$langmessage[140]= "Insert after";
$langmessage[141]= "Comment added";
$langmessage[142]= "Unknown error while saving comment";
$langmessage[143]= "Comments";
$langmessage[144]= "Poster";
$langmessage[145]= "Time offset from server";
$langmessage[146]= "Restricted page";
$langmessage[147]= "Only members can view this page";
$langmessage[148]= "Delete";
$langmessage[149]= "Image Deleted";
$langmessage[150]= "Setup Saved";
$langmessage[151]= "Date/time format";
$langmessage[152]= "Edit page";
$langmessage[153]= "Abandon changes";
$langmessage[154]= "Users";
$langmessage[155]= "Handle";
$langmessage[156]= "Repeat Password";
$langmessage[157]= "User level";
$langmessage[158]= "E-mail";
$langmessage[159]= "Default";
$langmessage[160]= "Access Level:";
$langmessage[161]= "Public";
$langmessage[162]= "Member";
$langmessage[163]= "Administrator";
$langmessage[164]= "Only administrators can view this page";
$langmessage[165]= "User profile";
$langmessage[166]= "First name";
$langmessage[167]= "Last name";
$langmessage[168]= "Website";
$langmessage[169]= "Location";
$langmessage[170]= "IP";
$langmessage[172]= "New User";
$langmessage[173]= "Save as new";
$langmessage[174]= "Delete comment";
$langmessage[175]= "Comment Deleted";
?>
